==> owncloud-4.0.4.tgz: owncloud/core/l10n/fi_FI.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Sovelluksen nimeä ei määritelty.",
"No category to add?" => "Ei lisättävää luokkaa?",
"This category already exists: " => "Tämä luokka on jo olemassa: ",
"Owncloud password reset" => "Owncloud-salasanan nollaus",
"ownCloud password reset" => "ownCloud-salasanan nollaus",
"Use the following link to reset your password: {link}" => "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
"You will receive a link to reset your password via Email." => "Saat sähköpostitse linkin nollataksesi salasanan.",
"Requested" => "Tilattu",
"Login failed!" => "Kirjautuminen epäonnistui!",
"Username" => "Käyttäjätunnus",
"Request reset" => "Tilaus lähetetty",
"Your password was reset" => "Salasanasi nollattiin",
"To login page" => "Kirjautumissivulle",
"New password" => "Uusi salasana",
"Reset password" => "Palauta salasana",
"Personal" => "Henkilökohtaiset",
"Users" => "Käyttäjät",
"Apps" => "Sovellukset",
"Admin" => "Hallinta",
"Help" => "Ohje",
"Access forbidden" => "Pääsy estetty",
"Cloud not found" => "Pilveä ei löydy",
"Edit categories" => "Muokkaa luokkia",
"Add" => "Lisää",
"Create an <strong>admin account</strong>" => "Luo <strong>ylläpitäjän tunnus</strong>",
"Password" => "Salasana",
"Advanced" => "Lisäasetukset",
"Data folder" => "Datakansio",
"Configure the database" => "Muokkaa tietokantaa",
"will be used" => "käytetään",
"Database user" => "Tietokannan käyttäjä",
"Database password" => "Tietokannan salasana",
"Database name" => "Tietokannan nimi",
"Database host" => "Tietokantapalvelin",
"Finish setup" => "Viimeistele asennus",
"web services under your control" => "verkkopalvelut hallinnassasi",
"Log out" => "Kirjaudu ulos",
"Settings" => "Asetukset",
"Lost your password?" => "Unohditko salasanasi?",
"remember" => "muista",
"Log in" => "Kirjaudu sisään",
"You are logged out." => "Olet kirjautunut ulos.",
"prev" => "edellinen",
"next" => "seuraava"
);

==> owncloud-4.5.7.tgz: owncloud/core/l10n/fi_FI.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Sovelluksen nimeä ei määritelty.",
"No category to add?" => "Ei lisättävää luokkaa?",
"This category already exists: " => "Tämä luokka on jo olemassa: ",
"Settings" => "Asetukset",
"January" => "Tammikuu",
"February" => "Helmikuu",
"March" => "Maaliskuu",
"April" => "Huhtikuu",
"May" => "Toukokuu",
"June" => "Kesäkuu",
"July" => "Heinäkuu",
"August" => "Elokuu",
"September" => "Syyskuu",
"October" => "Lokakuu",
"November" => "Marraskuu",
"December" => "Joulukuu",
"Choose" => "Valitse",
"Cancel" => "Peru",
"No" => "Ei",
"Yes" => "Kyllä",
"Ok" => "Ok",
"No categories selected for deletion." => "Luokkia ei valittu poistettavaksi.",
"Error" => "Virhe",
"Error while changing permissions" => "Virhe oikeuksia muuttaessa",
"Password protect" => "Suojaa salasanalla",
"Password" => "Salasana",
"Set expiration date" => "Aseta päättymispäivä",
"Expiration date" => "Päättymispäivä",
"Resharing is not allowed" => "Jakaminen uudelleen ei ole salittu",
"can edit" => "voi muokata",
"create" => "luo",
"update" => "päivitä",
"delete" => "poista",
"share" => "jaa",
"Password protected" => "Salasanasuojattu",
"Error setting expiration date" => "Virhe päättymispäivää asettaessa",
"ownCloud password reset" => "ownCloud-salasanan nollaus",
"Use the following link to reset your password: {link}" => "Voit palauttaa salasanasi seuraavassa osoitteessa: {link}",
"You will receive a link to reset your password via Email." => "Saat sähköpostitse linkin nollataksesi salasanan.",
"Requested" => "Tilattu",
"Login failed!" => "Kirjautuminen epäonnistui!",
"Username" => "Käyttäjätunnus",
"Request reset" => "Tilaus lähetetty",
"Your password was reset" => "Salasanasi nollattiin",
"To login page" => "Kirjautumissivulle",
"New password" => "Uusi salasana",
"Reset password" => "Palauta salasana",
"Personal" => "Henkilökohtaiset",
"Users" => "Käyttäjät",
"Apps" => "Sovellukset",
"Admin" => "Hallinta",
"Help" => "Ohje",
"Access forbidden" => "Pääsy estetty",
"Cloud not found" => "Pilveä ei löydy",
"Edit categories" => "Muokkaa luokkia",
"Add" => "Lisää",
"Create an <strong>admin account</strong>" => "Luo <strong>ylläpitäjän tunnus</strong>",
"Advanced" => "Lisäasetukset",
"Data folder" => "Datakansio",
"Configure the database" => "Muokkaa tietokantaa",
"will be used" => "käytetään",
"Database user" => "Tietokannan käyttäjä",
"Database password" => "Tietokannan salasana",
"Database name" => "Tietokannan nimi",
"Database tablespace" => "Tietokannan taulukkotila",
"Database host" => "Tietokantapalvelin",
"Finish setup" => "Viimeistele asennus",
"web services under your control" => "verkkopalvelut hallinnassasi",
"Log out" => "Kirjaudu ulos",
"Lost your password?" => "Unohditko salasanasi?",
"remember" => "muista",
"Log in" => "Kirjaudu sisään",
"You are logged out." => "Olet kirjautunut ulos.",
"prev" => "edellinen",
"next" => "seuraava"
);
